@@ -1,7 +1,7 @@
 /*
  
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
+Copyright (C) NEC Corporation 2012-2013. All Rights Reserved. 
+Copyright (C) NEC Soft, Ltd. 2012-2013. All Rights Reserved. 
  
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
@@ -288,7 +288,7 @@ PURPOSE.  See the GNU General Public License for more details.
 				,modal   : true
 				,autoOpen: true
 				,width   : 600
-				,height  : 150
+				,height  : "auto"
 				,position: ["center", 125]
 				,close   : function(){
 					// Remove dialog
@@ -325,12 +325,20 @@ PURPOSE.  See the GNU General Public License for more details.
 		 *   dlg: object content:
 		 *     message: string or object
 		 *     level  : number
+		 *   logoutWhenError: boolean
+		 *     true   : logout after show error message (default)
+		 *     false  : not logout after show error message
 		 */
-		openPromptDlg: function(dlg){
+		openPromptDlg: function(dlg, logoutWhenError){
 			if(Exist_Dialogs == true)
 			{
 				return;
 			}
+			
+			if ((logoutWhenError === undefined) || (logoutWhenError != false)){
+				logoutWhenError = true;
+			}
+			
 			Exist_Dialogs = true;
 			var msg
 			,level
@@ -408,9 +416,11 @@ PURPOSE.  See the GNU General Public License for more details.
 					delete $dlg;
 					
 					// Check level
-					if(level === __.LEVEL_ERROR){
+					if((level === __.LEVEL_ERROR) && (logoutWhenError === true)){
 						__.logout();
 					}
+					
+					Exist_Dialogs = false;
 				}
 				,buttons: [
 					{
