@@ -356,9 +356,14 @@ cm._fnview = {
 					// Prevent for load grid
 					if(check_value !== true){
 						i._stop = true;
+						if((i.getGridParam("postData").action == "confirmed")
+								|| (i.getGridParam("postData").action == "unconfirm")
+								|| (i.getGridParam("postData").action == "batchconfirm")){
+							i._stop = false;
+						}
 					}
 					
-					}
+				}
 			}
 			
 			,/*
