@@ -1,7 +1,7 @@
 /*
  
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
+Copyright (C) NEC Corporation 2012-2013. All Rights Reserved. 
+Copyright (C) NEC Soft, Ltd. 2012-2013. All Rights Reserved. 
  
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
@@ -60,8 +60,13 @@ PURPOSE.  See the GNU General Public License for more details.
 		,failed          : "${failed}"
 		,filtered_list   : "${filtered.list}"
 		,invalid         : "${invalid}"
+		,invalidInput    : "${message.hinemos.1}"
+		,inputOverRange  : "${message.hinemos.8}"
 		,job             : "${job}"
 		,job_id          : "${job.id}"
+		,job_stop_force       : "${job.stop.force}"
+		,job_stop_maintenance : "${job.stop.maintenance}"
+		,job_stop_skip        : "${job.stop.skip}"
 		,message         : "${message}"
 		,minute          : "${minute}"
 		,month_names     : (new String("${month.names}")).split(",")
@@ -73,15 +78,20 @@ PURPOSE.  See the GNU General Public License for more details.
 		,ok_o            : "${lang.ok_o}"
 		,open_perspective: "${open.perspective}"
 		,open_perspective_title: "${open.perspective.title}"
+		,operation_job_failed : "${message.job.34}"
 		,period_format   : "${js.format.period}"
+		,run_job_confirm : "${message.job.run.confirm}"
 		,scope           : "${lang.scope}"
 		,select_job      : "${select.job}"
 		,select_job_errormsg_title : "${select.job.errormsg.title}"
 		,select_row      : "${select.row}"
 		,session_id      : "${session.id}"
 		,schedule_id     : "${schedule.id}"
+		,specify_end_value : "${message.job.21}"
 		,specify_job     : "${message.job.1}"
 		,specified_period: "${specified.period}"
+		,start           : "${start}"
+		,stop            : "${stop}"
 		,valid           : "${valid}"
 		,value           : "${lang.value}"
 		,warning         : "${warning}"
@@ -91,6 +101,10 @@ PURPOSE.  See the GNU General Public License for more details.
 		,perspectiveP    : "${perspectiveP}"
 		,leftBracket     : "${left.bracket}"
 		,rightBracket    : "${right.bracket}"
+		,agent_restart_confirmed_1 : "${agent.restart.confirmed.1}"
+		,agent_restart_confirmed_2 : "${agent.restart.confirmed.2}"
+		,agent_update_confirmed_1  : "${agent.update.confirmed.1}"
+		,agent_update_confirmed_2  : "${agent.update.confirmed.2}"
 	}
 	;
 	
