@@ -1,7 +1,7 @@
 /*
  
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
+Copyright (C) NEC Corporation 2012-2013. All Rights Reserved. 
+Copyright (C) NEC Soft, Ltd. 2012-2013. All Rights Reserved. 
  
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
@@ -137,10 +137,17 @@ var fn = function (_view){
 							// Disable button "detail"
 							if(grid.getGridParam("selarrrow").length != 1) {
 								_.$btns.children("#detail").attr("disabled", true);
+								_.$btns.children("#detail").addClass("ui-state-default");
 							}
 							// Disable button "confirmed"
 							if(_.getRowsUnconfirmed().length <= 0){
 								_.$btns.children("#confirmed").attr("disabled", true);
+								_.$btns.children("#confirmed").addClass("ui-state-default");
+							}
+							// Disable button "unconfirm"
+							if(_.getRowsConfirmed().length <= 0){
+								_.$btns.children("#unconfirm").attr("disabled", true);
+								_.$btns.children("#unconfirm").addClass("ui-state-default");
 							}
 							// Set priority bar
 							_.setPriorityStatusBar();
@@ -221,17 +228,29 @@ var fn = function (_view){
 							// Check for setting status  of detail button
 							if(length != 1){
 								$btns.children("#detail").attr("disabled", true);
+								$btns.children("#detail").addClass("ui-state-default");
 							}else{
 								// Actually, length = 1, because when the action
 								// onSelectRow, at least, the grid has a row
 								// which is selected
 								$btns.children("#detail").attr("disabled", false);
+								$btns.children("#detail").removeClass("ui-state-default");
 							}
 							
 							if(_.getRowsUnconfirmed().length > 0){
 								$btns.children("#confirmed").attr("disabled", false);
+								$btns.children("#confirmed").removeClass("ui-state-default");
 							}else{
 								$btns.children("#confirmed").attr("disabled", true);
+								$btns.children("#confirmed").addClass("ui-state-default");
+							}
+							
+							if(_.getRowsConfirmed().length > 0){
+								$btns.children("#unconfirm").attr("disabled", false);
+								$btns.children("#unconfirm").removeClass("ui-state-default");
+							}else{
+								$btns.children("#unconfirm").attr("disabled", true);
+								$btns.children("#unconfirm").addClass("ui-state-default");
 							}
 						}
 						,gridComplete: function(){
@@ -255,18 +274,28 @@ var fn = function (_view){
 					grid.hideCol("cb"); // Hide check box
 					grid.controlSize();
 					
-					// Bind context menu for grid(right click)
+					// Bind context menu for grid (right click)
 					grid.contextMenu(
 						"menu_rightclick"
 						,{
 							onContextMenu: function(event, menu){
 								var row_id = $(event.target).closest("tr").attr("id")
 								,selrows   = grid.getGridParam("selarrrow")
+								,$btns  = _.$btns
 								;
 								
 								if(selrows.length){
 									if($.inArray(row_id, selrows) == -1){
 										grid.jqGrid("resetSelection");
+										// Set button status
+										$btns.children("#confirmed").attr("disabled", true);
+										$btns.children("#confirmed").addClass("ui-state-default");
+										
+										$btns.children("#unconfirm").attr("disabled", true);
+										$btns.children("#unconfirm").addClass("ui-state-default");
+										
+										$btns.children("#detail").attr("disabled", true);
+										$btns.children("#detail").addClass("ui-state-default");
 									}else{
 										grid.jqGrid("setSelection", row_id, false);
 									}
@@ -282,13 +311,19 @@ var fn = function (_view){
 								}else{
 									$mn.children("#confirmed").addClass("ui-state-disabled");
 								}
-                                
-                                if(grid.getGridParam("selarrrow").length != 1) {
-                                    $mn.children("#detail").addClass("ui-state-disabled");
-                                }else{
-                                    $mn.children("#detail").removeClass("ui-state-disabled");
-                                }
-                                
+								
+								if(_.getRowsConfirmed().length > 0){
+									$mn.children("#unconfirm").removeClass("ui-state-disabled");
+								}else{
+									$mn.children("#unconfirm").addClass("ui-state-disabled");
+								}
+								
+								if(grid.getGridParam("selarrrow").length != 1) {
+									$mn.children("#detail").addClass("ui-state-disabled");
+								}else{
+									$mn.children("#detail").removeClass("ui-state-disabled");
+								}
+								
 								return true;
 							}
 							,container   : grid.$ctn
@@ -300,6 +335,10 @@ var fn = function (_view){
 									_.confirmAction();
 									return true;
 								}
+								,unconfirm: function(e){
+									_.unconfirmAction();
+									return true;
+								}
 							}
 						}
 					);
@@ -334,9 +373,7 @@ var fn = function (_view){
 		 * Refresh data
 		 */
 		refreshData: function(){
-            /** Bug_11 */
 			this.grid.refreshData(null, true);
-            /***********/
 		}
 		
 		,/*
@@ -377,7 +414,7 @@ var fn = function (_view){
 							$(this).click(function(e){
 								var $i = $(this)
 								,$div  = $i.siblings("div:first")
-                                ,$title = $i.parent().siblings("td:first")
+								,$title = $i.parent().siblings("td:first")
 								;
 								if($div.length != 0){
 									__.openTextDlg({
@@ -434,9 +471,8 @@ var fn = function (_view){
 									$.extend(post_data, {filter: true});
 									
 									// Refresh data
-									/** Bug_11 */
 									_.grid.refreshData(post_data, true);
-									/***********/
+									
 									// Set caption
 									_.grid.setCaption(__.getLang("filtered_list"));
 									
@@ -461,6 +497,48 @@ var fn = function (_view){
 				}
 				,url  : "get_event_filter_property"
 			});
+			
+			// Declare batch confirm dialog
+			__.crePropActnDlg.call(_, "batchconfirm", {
+				option: {
+					title   : _pers.getTitle("batchconfirm")
+					,width  : 400
+					,height : 400
+					,open   : function(){
+						$(this).siblings('div.ui-dialog-buttonpane:first').find("button:eq(0)").focus();
+					}
+					,buttons: [
+						{
+							text  : __.getLang("ok_o")
+							,click: function(){
+								_.batchconfirm.execute(function(post_data){
+									var _ = this;
+
+									// Extend batch confirm action
+									$.extend(post_data, {action: "batchconfirm"});
+									
+									// Refresh data
+									_.grid.refreshData(post_data, true);
+
+								});
+								
+								// Clear current data in batch confirm dialog
+								_.batchconfirm.reset("batchconfirm");
+								_.batchconfirm.storeValues();
+								
+								$(this).dialog("close");
+							}
+						}
+						,{
+							text  : __.getLang("cancel")
+							,click: function(){
+								$(this).dialog("close");
+							}
+						}
+					]
+				}
+				,url  : "get_event_batch_confirm_property"
+			});
 		}
 		
 		,/*
@@ -473,11 +551,21 @@ var fn = function (_view){
 			;
 			
 			// Bind actions for button in left of pane
-			// Bind detail
+			// Bind confirmed
 			btns.children("#confirmed").click(function(){
 				_.confirmAction();
 			});
 			
+			// Bind unconfirm
+			btns.children("#unconfirm").click(function(){
+				_.unconfirmAction();
+			});
+			
+			// Bind batch confirm
+			btns.children("#batchconfirm").click(function(){
+				_.batchconfirm.open();
+			});
+			
 			// Bind detail
 			btns.children("#detail").click(function(){
 				_.getDetail();
@@ -487,9 +575,7 @@ var fn = function (_view){
 			btns.children("#filter").click(function(){
 				if(_.filter_active){
 					// Inactive filter for filter grid
-					/** Bug_11 */
 					grid.refreshData({filter: false}, true);
-					/***********/
 					grid.setCaption(_._caption);
 					
 					// Process CSS for button
@@ -503,9 +589,7 @@ var fn = function (_view){
 			
 			// Bind update grid data
 			btns.children("#update").click(function(){
-				/** Bug_11 */
 				_.grid.refreshData(null, true);
-				/***********/
 			});
 			
 			// Bind toggle left pane
@@ -566,6 +650,28 @@ var fn = function (_view){
 			return list;
 		}
 		
+		,/*
+		 * Get rows in selection list have confirmed value is confirmed 
+		 */
+		getRowsConfirmed: function(){
+			var _     = this
+			,list     = []
+			,col_name = "confirmed"
+			,grid     = _.grid
+			,selrows  = grid.getGridParam("selarrrow")
+			,cnt_row  = selrows.length
+			;
+			
+			while(cnt_row--){
+				var row_id = selrows[cnt_row];
+				if(grid.getCell(row_id, col_name) == TYPE_CONFIRMED){
+					list[list.length] = row_id;
+				}
+			}
+			
+			return list;
+		}
+		
 		,/*
 		 * Action for confirm
 		 */
@@ -596,7 +702,41 @@ var fn = function (_view){
 					actionData: act_data
 					,action   : "confirmed"
 					,numData  : act_data.length
-				});
+				}, true);
+			}
+		}
+		
+		,/*
+		 * Action for unconfirm
+		 */
+		unconfirmAction: function(){
+			var _    = this
+			,grid    = _.grid
+			,list    = _.getRowsConfirmed()
+			,cnt_row = list.length
+			;
+			
+			if(cnt_row > 0){
+				// Initialize post data with name of action is unconfirmed
+				var act_data = [];
+				while(cnt_row--){
+					var row_id = list[cnt_row]
+					,row_data  = grid.getRowData(row_id)
+					,post_row  = {};
+					;
+					for (var col_nm in row_data){
+						var value = row_data[col_nm];
+						post_row[col_nm] = $.jgrid.htmlEncode(value);
+					}
+					act_data[cnt_row] = post_row;
+				}
+				
+				// Unconfirm action
+				grid.refreshData({
+					actionData: act_data
+					,action   : "unconfirm"
+					,numData  : act_data.length
+				}, true);
 			}
 		}
 	});
