@@ -105,9 +105,20 @@ var fn = function(_view){
 							// Set priority bar
 							_.setPriorityStatusBar();
 						}
+						,ondblClickRow: function(rowid) {
+                            var row_data = grid.getRowData(rowid);
+                            var node_key = __.getNodeKey(_.getTree(), row_data.facilityId);
+                            
+                            if (typeof node_key != 'undefined') {
+                                var tree = $(_.tree).dynatree("getTree");
+                                tree.activateKey(node_key);
+                            }
+						}
 					});
 				
-					grid.processData(data_respond);
+					/** Bug_11 */
+					grid.processData(data_respond, ["facilityId"]);
+					/***********/
 					grid.controlSize();
 				}
 				,error   : __.loadDataError
@@ -128,10 +139,10 @@ var fn = function(_view){
 			var _ = this;
 			
 			_.tree.refreshData(tree);
-			
+			_.facility_id = "";
 			_.grid.refreshData({
 				facilityId: ""
-			});
+			}, true);
 			
 			_.setCaption("");
 		}
@@ -140,7 +151,9 @@ var fn = function(_view){
 		 * Refresh data
 		 */
 		refreshData: function(){
-			this.grid.refreshData();
+			/** Bug_11 */
+			this.grid.refreshData(null, true);
+			/***********/
 		}
 		
 		,/*
@@ -153,7 +166,9 @@ var fn = function(_view){
 			// Bind actions for button in left of pane
 			// Bind update grid data
 			_btns.children("#update").click(function(){
-				_.grid.refreshData();
+				/** Bug_11 */
+				_.grid.refreshData(null, true);
+				/***********/
 			});
 			// Bind toggle left pane
 			_btns.children("#toggle_view").click(function(){
