@@ -123,7 +123,11 @@ var fn = function(_view){
 						}
 					});
 							
-					grid.processData(data_respond);
+					/** Bug_11 */
+					grid.processData(data_respond, ['priority', 'pluginId', 'monitorId', 'monitorDetailId',
+						'facilityId', 'application', 'outputTime', 'messageId', 'message'],
+						{outputTime: 'hnmDatetime'});
+					/***********/
 					grid.controlSize();
 					
 					// Bind action for grid
@@ -157,10 +161,10 @@ var fn = function(_view){
 			var _ = this;
 			
 			_.tree.refreshData(tree);
-			
+			_.facility_id = "";
 			_.grid.refreshData({
 				facilityId: ""
-			});
+			}, true);
 			
 			_.setCaption("");
 		}
@@ -169,7 +173,9 @@ var fn = function(_view){
 		 * Refresh data
 		 */
 		refreshData: function(){
-			this.grid.refreshData();
+			/** Bug_11 */
+			this.grid.refreshData(null, true);
+			/***********/
 		}
 		
 		,/*
@@ -205,7 +211,9 @@ var fn = function(_view){
 									$.extend(post_data, {filter: true});
 									
 									// Refresh data
-									_.grid.refreshData(post_data)
+									/** Bug_11 */
+									_.grid.refreshData(post_data, true);
+									/***********/
 									
 									// Store filter active
 									_.filter_active = true;
@@ -223,6 +231,7 @@ var fn = function(_view){
 						,{
 							text  : __.getLang("cancel")
 							,click: function(){
+								_.filter.storeValues();
 								$(this).dialog("close");
 							}
 						}
@@ -245,7 +254,9 @@ var fn = function(_view){
 			btns.children("#filter").click(function(){
 				if(_.filter_active){
 					// Inactive filter for filter grid
-					grid.refreshData({filter: false});
+					/** Bug_11 */
+					grid.refreshData({filter: false}, true);
+					/***********/
 					grid.setCaption(_._caption);
 					
 					// Process CSS for button
@@ -259,7 +270,9 @@ var fn = function(_view){
 			
 			// Bind update grid data
 			btns.children("#update").click(function(){
-				_.grid.refreshData();
+				/** Bug_11 */
+				_.grid.refreshData(null, true);
+				/***********/
 			});
 			// Bind toggle left pane
 			btns.children("#toggle_view").click(function(){
