@@ -68,6 +68,7 @@ var fn = function(_view){
 				return;
 			}
 			
+			$("#load_grid_repository_assigned_scopes").show();
 			// Reload grid
 			grid.refreshData({facilityId: facility_id});
 		}
@@ -133,9 +134,9 @@ var fn = function(_view){
 						}
 					});
 				
-					grid.processData(data_respond);
-					grid.controlSize();
+					grid.processData(data_respond, ["facilityId"]);
 					_.setCaption();
+					grid.controlSize();
 				}
 				,error   : __.loadDataError
 			});
@@ -151,7 +152,8 @@ var fn = function(_view){
 			// Bind actions for button in left of pane
 			// Bind update grid data
 			_btns.children("#update").click(function(){
-				_.grid.refreshData();
+				$("#load_grid_repository_assigned_scopes").show();
+				_.grid.refreshData(null, true);
 			});
 		}
 	});
