@@ -96,8 +96,8 @@ var fn = function(_view){
 							
 							_.updateAssignedScopes(facility_id, facility_name);
 							_.updateNodeProperty(facility_id);
-						}
-						,loadComplete: function() {
+                            
+						},loadComplete: function() {
 							// Reload Repository[AssignedScopes] and Repository[NodeProperty] after 
 							// Repository[Node] loaded
 							var curent_facility_id   = _pers["assigned_scopes"].__facility_id;
@@ -181,6 +181,7 @@ var fn = function(_view){
 							,{
 								text  : __.getLang("cancel")
 								,click: function(){
+									_.filter.storeValues();
 									$(this).dialog("close");
 								}
 							}
