@@ -23,8 +23,7 @@ var fn = function(_view){
 	;
 	
 	 var view = $.extend({}, __._fnview_grid, {
-		facility_id: ""
-		,load_flg    : false
+		load_flg    : false
 		,/*
 		 * Update data when click on view 'node' content
 		 */
@@ -84,7 +83,7 @@ var fn = function(_view){
 						$(this).click(function(e){
 							var $i = $(this)
 							,$div  = $i.siblings("div:first")
-							,$title = $i.parent().siblings("td:visible:first")
+                            ,$title = $i.parent().siblings("td:visible:first")
 							;
 							
 							if($div.length != 0){
@@ -111,7 +110,6 @@ var fn = function(_view){
 				}
 				, loadComplete: function() {
 					var facility_id = _view.__facility_id;
-					
 					if(facility_id === _.facility_id){
 						_.load_flg = false;
 					}else{
