@@ -18,20 +18,25 @@ package com.necsoft.hinemos.webclient.accesscontrol;
 
 public class AccessControlConstants {
     // Pattern for validation
-    public static final String USER_ID_PARTERN = "^[0-9a-zA-Z]*$";
-
-    public static final String URL_SERVER_PARTERN = "^(jnp\\u003a\\u002f\\u002f)?[a-zA-Z0-9][a-zA-Z0-9\\u002d\\u002e]*(\\u003a\\d{0,5})?$";
+    public static final String USER_ID_PARTERN = "^[0-9a-zA-Z\\u002d\\u005f]*$";
 
+    //public static final String URL_SERVER_PARTERN = "^(jnp\\u003a\\u002f\\u002f)?[a-zA-Z0-9][a-zA-Z0-9\\u002d\\u002e]*(\\u003a\\d{0,5})?$";
+    public static final String URL_SERVER_PARTERN = "^(http\\u003a\\u002f\\u002f)?[a-zA-Z0-9][a-zA-Z0-9\\u002d\\u002e]*(\\u003a\\d{0,5})?[a-zA-Z0-9\\u002d\\u002e\\u002f]*$";
     // Default inputs
     public static final String HINEMOS_USER_DEFAULT = "hinemos";
 
-    public static final String HINEMOS_JNP_PROTOCAL_DEFAULT = "jnp://";
-
-    public static final String HINEMOS_JNP_PORT_DEFAULT = ":1099";
+    //public static final String HINEMOS_JNP_PROTOCAL_DEFAULT = "jnp://";
+    public static final String HINEMOS_HTTP_PROTOCAL_DEFAULT = "http://";
+    
+    //public static final String HINEMOS_JNP_PORT_DEFAULT = ":1099";
+    public static final String HINEMOS_HTTP_PORT_DEFAULT = ":8080/HinemosWS/";
 
     // Views
     public static final String VIEW_LOGIN_JSP = "/jsp/accesscontrol/login.jsp";
 
     // User
     public static final String USER_BEAN = "userBean";
+    
+    //LOGIN MANAGER
+    public static final String LOGIN_MANAGER = "loginManager";
 }
