@@ -16,12 +16,6 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.necsoft.hinemos.webclient.accesscontrol.business;
 
-import java.rmi.RemoteException;
-
-import javax.ejb.CreateException;
-import javax.naming.NamingException;
-import javax.security.auth.login.LoginException;
-
 import com.necsoft.hinemos.webclient.accesscontrol.form.UserForm;
 import com.necsoft.hinemos.webclient.util.LoginManager;
 
@@ -39,14 +33,9 @@ public class LoginAuthBusiness {
      * @param form : UserForm
      * @param loginManager : LoginManager
      * @return void
-     * @throws NamingException
-     * @throws LoginException
-     * @throws RemoteException
-     * @throws CreateException     * 
-     */
-    public void loginAuth(UserForm form, LoginManager loginManager)
-            throws NamingException, LoginException, RemoteException,
-            CreateException {
+     * @throws Exception 
+     **/
+    public void loginAuth(UserForm form, LoginManager loginManager) throws Exception {
         loginManager.login(form.getUserName(), form.getPassword(),
                 form.getUrlServer());
     }
