@@ -77,11 +77,17 @@ public class JobTriggerTypeConstant {
      * @return
      */
     public static int stringToType(String string) {
-        if (string.equals(WebMessages.getString("schedule", Locale.JAPAN))) { //スケジュール（文字列)
+        if ((string.equals(WebMessages.getString("schedule", Locale.JAPAN)))
+                || (string.equals(WebMessages.getString("schedule", Locale.ENGLISH)))) {
+            //スケジュール（文字列)
             return TYPE_SCHEDULE;
-        } else if (string.equals(WebMessages.getString("trigger.manual", Locale.JAPAN))) { //手動実行（文字列）
+        } else if ((string.equals(WebMessages.getString("trigger.manual", Locale.JAPAN)))
+                || (string.equals(WebMessages.getString("trigger.manual", Locale.ENGLISH)))) {
+                //手動実行（文字列）
             return TYPE_MANUAL;
-        } else if (string.equals(WebMessages.getString("trigger.monitor", Locale.JAPAN))) { //監視連動（文字列)
+        } else if ((string.equals(WebMessages.getString("trigger.monitor", Locale.JAPAN)))
+                || (string.equals(WebMessages.getString("trigger.monitor", Locale.ENGLISH)))){ 
+                //監視連動（文字列)
             return TYPE_MONITOR;
         }
         return -1;
