@@ -94,26 +94,36 @@ public class StatusConstant {
      * @param type
      * @return
      */
-    public static int stringToType(String string, Locale locale) {
-        if (string.equals(WebMessages.getString("running", locale))) {
+    public static int stringToType(String string) {
+        if ((string.equals(WebMessages.getString("running", Locale.JAPAN))) 
+                || (string.equals(WebMessages.getString("running", Locale.ENGLISH)))){
             return TYPE_RUNNING;        //実行中(状態の種別)
-        } else if (string.equals(WebMessages.getString("end", locale))) {
+        } else if ((string.equals(WebMessages.getString("end", Locale.JAPAN)))
+                || (string.equals(WebMessages.getString("end", Locale.ENGLISH)))){
             return TYPE_END;            //終了(状態の種別)
-        } else if (string.equals(WebMessages.getString("wait", locale))) {
+        } else if ((string.equals(WebMessages.getString("wait", Locale.JAPAN)))
+                || (string.equals(WebMessages.getString("wait", Locale.ENGLISH)))){
             return TYPE_WAIT;           //待機(状態の種別)
-        } else if (string.equals(WebMessages.getString("stopping", locale))) {
+        } else if ((string.equals(WebMessages.getString("stopping", Locale.JAPAN))) 
+                || (string.equals(WebMessages.getString("stopping", Locale.ENGLISH)))) {
             return TYPE_STOPPING;       //停止処理中(状態の種別)
-        } else if (string.equals(WebMessages.getString("stop.at.once", locale))) {
+        } else if ((string.equals(WebMessages.getString("stop.at.once", Locale.JAPAN)))
+                || (string.equals(WebMessages.getString("stop.at.once", Locale.ENGLISH)))){
             return TYPE_STOP;           //コマンド停止(状態の種別)
-        } else if (string.equals(WebMessages.getString("reserving", locale))) {
+        } else if ((string.equals(WebMessages.getString("reserving", Locale.JAPAN))) 
+                || (string.equals(WebMessages.getString("reserving", Locale.ENGLISH)))){
             return TYPE_RESERVING;      //保留中(状態の種別)
-        } else if (string.equals(WebMessages.getString("modified", locale))) {
+        } else if ((string.equals(WebMessages.getString("modified", Locale.JAPAN)))
+                || (string.equals(WebMessages.getString("modified", Locale.ENGLISH)))){
             return TYPE_MODIFIED;       //変更済(状態の種別)
-        } else if (string.equals(WebMessages.getString("start.error", locale))) {
+        } else if ((string.equals(WebMessages.getString("start.error", Locale.JAPAN)))
+                || (string.equals(WebMessages.getString("start.error", Locale.ENGLISH)))){
             return TYPE_ERROR;          //起動失敗(状態の種別)
-        } else if (string.equals(WebMessages.getString("skip", locale))) {
+        } else if ((string.equals(WebMessages.getString("skip", Locale.JAPAN)))
+                || (string.equals(WebMessages.getString("skip", Locale.ENGLISH)))){
             return TYPE_SKIP;           //スキップ(状態の種別)
-        } else if (string.equals(WebMessages.getString("suspend", locale))) {
+        } else if ((string.equals(WebMessages.getString("suspend", Locale.JAPAN)))
+                || (string.equals(WebMessages.getString("suspend", Locale.ENGLISH)))){
             return TYPE_SUSPEND;        //中断(状態の種別)
         }
         return -1;
