@@ -1,7 +1,7 @@
 /*
  
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
+Copyright (C) NEC Corporation 2012-2013. All Rights Reserved. 
+Copyright (C) NEC Soft, Ltd. 2012-2013. All Rights Reserved. 
  
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
@@ -29,8 +29,13 @@ public class Constants {
 
     // Set name of repository filter node properties
     public static final String NODE_FILTER_PROPERTIES = "node_filter_properties";
+    public static final String NODE_FILTER_PROPERTIES_LANG = "node_filter_properties_lang";
 
     public static final String HISTORY_FILTER_PROPERTIES = "history_filter_properties";
+    public static final String HISTORY_FILTER_PROPERTIES_LANG = "history_filter_properties_lang";
+
+    // Set name of operation job properties
+    public static final String OPERATION_JOB_PROPERTIES = "operation_job_properties";
 
     public static final String ACTION_DATA_REQUEST = "actionData";
 
