@@ -1,7 +1,7 @@
 /*
  
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
+Copyright (C) NEC Corporation 2012-2013. All Rights Reserved. 
+Copyright (C) NEC Soft, Ltd. 2012-2013. All Rights Reserved. 
  
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
@@ -27,6 +27,7 @@ import java.util.Locale;
 import java.util.Map;
 import org.apache.commons.lang3.StringEscapeUtils;
 import com.clustercontrol.bean.PropertyConstant;
+import com.clustercontrol.jobmanagement.bean.JobOperationConstant;
 import com.clustercontrol.repository.bean.NodeConstant;
 import com.necsoft.hinemos.webclient.bean.Property;
 import com.necsoft.hinemos.webclient.bean.PropertyValue;
@@ -82,6 +83,11 @@ public class DataProcess {
 
     public static final Map<String, Object> getRowFromProperty(
             Property property, int level) {
+        return getRowFromProperty(property, level, false);
+    }
+
+    public static final Map<String, Object> getRowFromProperty(
+            Property property, int level, boolean valueWithChild) {
         Map<String, Object> data = new HashMap<String, Object>();
         Property proParent;
 
@@ -90,8 +96,8 @@ public class DataProcess {
         String name;
         String value = HtmlEncode.SPACE;
         String parent = JsConstant.TREEGRID_ROOT_PARENT;
-        Boolean isLeaf = false;
-        Boolean expanded = false;
+        boolean isLeaf = false;
+        boolean expanded = false;
 
         // Get id, name
         id = property.getID();
@@ -104,9 +110,12 @@ public class DataProcess {
         }
 
         if ((property.getChildren() == null)
-                || (property.getChildren().length < 1)) {
+                || ((property.getChildren().length < 1) || (valueWithChild))) {
             // This is a leaf which doesn't have any child
-            isLeaf = true;
+            if (property.getChildren().length < 1) {
+                isLeaf = true;
+            }
+            
             StringBuffer buf = new StringBuffer();
 
             // Set value properly
@@ -129,6 +138,16 @@ public class DataProcess {
                     int selLen = selValues.length;
                     if (selDisplays.length == selLen) {
                         for (int cnt = 0; cnt < selLen; cnt++) {
+                            String display = "";
+                            if (selDisplays[cnt] instanceof HashMap) {
+                                HashMap map = (HashMap) selDisplays[cnt];
+
+                                //子Propertyを取得
+                                display = map.get(PropertyConstant.MAP_VALUE)
+                                                                    .toString();
+                            } else {
+                                display = selDisplays[cnt].toString();
+                            }
                             buf.append("<option value='");
                             buf.append(selValues[cnt].toString());
                             buf.append("'");
@@ -139,7 +158,7 @@ public class DataProcess {
                             }
 
                             buf.append(">");
-                            buf.append(selDisplays[cnt].toString());
+                            buf.append(display);
                             buf.append("</option>");
                         }
                     }
@@ -164,7 +183,19 @@ public class DataProcess {
                     buf.append("' readonly='readonly");
                 } else {
                     buf.append(CssClass.GRID_INPUT_NORMAL);
+                    // Check for edit permission
+                    if (property.getModify() == PropertyConstant.MODIFY_NG) {
+                        buf.append("' readonly='readonly");
+                    }
                     buf.append("' value='");
+                    
+                    if (editor.equals(PropertyConstant.EDITOR_NUM)) {
+                        buf.append("' min='");
+                        buf.append(property.getLowerBound());
+                        buf.append("' max='");
+                        buf.append(property.getUpperBound());
+                    }
+                    
                     buf.append(propValue);
                 }
 
@@ -545,4 +576,44 @@ public class DataProcess {
 
         return result;
     }
+
+    /**
+     * This method is used for convert data row of grid to TreeGridJson data.
+     * 
+     * @author thundh
+     * @since 2013/01/16
+     * @param propertyInfo
+     *            : Property
+     * @return TreeGridJson
+     */
+    public static final TreeGridJson doConvertOperationInfoToJson(
+        Property propertyInfo) {
+
+        // Create JSON
+        TreeGridJson result = new TreeGridJson();
+        Object[] propertiesL0 = propertyInfo.getChildren();
+        int lengtL0 = propertiesL0.length;
+
+        // Create data
+        for (int cntL0 = 0; cntL0 < lengtL0; cntL0++) {
+            Property propertyL0 = (Property) propertiesL0[cntL0];
+            // Set data row
+            if (propertyL0.getID().equals(JobOperationConstant.CONTROL)) {
+                result.addData(DataProcess.getRowFromProperty(
+                    propertyL0, JsConstant.TREEGRID_ROOT_LEVEL, true));
+            } else {
+                result.addData(DataProcess.getRowFromProperty(propertyL0));
+            }
+            Object[] propertiesL1 = propertyL0.getChildren();
+            if ((propertiesL1 != null) && (propertiesL1.length > 0)) {
+                int lengtL1 = propertiesL1.length;
+                for (int cntL1 = 0; cntL1 < lengtL1; cntL1++) {
+                    Property propertyL1 = (Property) propertiesL1[cntL1];
+                    result.addData(DataProcess
+                            .getRowFromProperty(propertyL1, 1));
+                }
+            }
+        }
+        return result;
+    }
 }
