@@ -17,11 +17,12 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.necsoft.hinemos.webclient.jobmanagement.servlet;
 
 import java.io.IOException;
-import java.util.Locale;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
+import javax.servlet.http.HttpSession;
 import com.necsoft.hinemos.webclient.bean.Property;
+import com.necsoft.hinemos.webclient.common.Constants;
 import com.necsoft.hinemos.webclient.common.DataProcess;
 import com.necsoft.hinemos.webclient.exception.HinemosWebException;
 import com.necsoft.hinemos.webclient.jobmanagement.business.GetHistoryFilterPropertyBusiness;
@@ -60,7 +61,7 @@ public class GetHistoryFilterPropertyServlet extends CommonServlet {
 
         try {
             //Get data
-            Property propertyHistory = doLoadProperty(request.getLocale());
+            Property propertyHistory = doLoadProperty(request);
           
             //Convert data to JSON structure
             result = DataProcess.doConvertFilterToJson(propertyHistory);
@@ -76,16 +77,29 @@ public class GetHistoryFilterPropertyServlet extends CommonServlet {
     /**
      * Get History Property
      * 
-     * @param locale
-     *            : Locale
+     * @param request
+     *            : HttpServletRequest
      * @return Property
      * @throws HinemosWebException
      */
-    private Property doLoadProperty(Locale locale) throws HinemosWebException {
-        Property propertyHistory = null;
-        GetHistoryFilterPropertyBusiness business = new GetHistoryFilterPropertyBusiness();
-        propertyHistory = business.getHistoryFilterProperty(locale);
 
-        return propertyHistory;
-    }
+    private Property doLoadProperty(HttpServletRequest request) throws HinemosWebException {
+        // 中間変数を宣言
+        HttpSession session = request.getSession(true);
+        Property propertyHistory = (Property) session.
+                getAttribute(Constants.HISTORY_FILTER_PROPERTIES);
+        String lang = (String)session.
+                getAttribute(Constants.HISTORY_FILTER_PROPERTIES_LANG);
+        String cur_lang = request.getLocale().getLanguage();
+        // イベント情報一覧を取得
+        if ((propertyHistory == null) || !(cur_lang.equals(lang))) {
+            GetHistoryFilterPropertyBusiness business = new GetHistoryFilterPropertyBusiness();
+            propertyHistory = business.getHistoryFilterProperty(request.getLocale());
+            session.setAttribute(Constants.HISTORY_FILTER_PROPERTIES,
+                    propertyHistory);
+            session.setAttribute(Constants.HISTORY_FILTER_PROPERTIES_LANG,
+                    cur_lang);
+        }
+         return propertyHistory;
+     }
 }
\ No newline at end of file
