@@ -17,15 +17,14 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.necsoft.hinemos.webclient.jobmanagement.servlet;
 
 import java.io.IOException;
-import java.util.List;
-
+import java.util.ArrayList;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
-
-import org.jnp.interfaces.NamingContext;
-
-import com.clustercontrol.bean.Property;
+import javax.servlet.http.HttpSession;
+import com.necsoft.hinemos.webclient.accesscontrol.AccessControlConstants;
+import com.necsoft.hinemos.webclient.bean.Property;
+import com.necsoft.hinemos.webclient.common.DataProcess;
 import com.necsoft.hinemos.webclient.exception.HinemosWebAccessException;
 import com.necsoft.hinemos.webclient.exception.HinemosWebException;
 import com.necsoft.hinemos.webclient.exception.HinemosWebRemoteException;
@@ -33,18 +32,19 @@ import com.necsoft.hinemos.webclient.jobmanagement.business.GetHistoryBusiness;
 import com.necsoft.hinemos.webclient.jobmanagement.business.GetHistoryFilterPropertyBusiness;
 import com.necsoft.hinemos.webclient.jobmanagement.form.HistoryForm;
 import com.necsoft.hinemos.webclient.json.CommonJson;
-import com.necsoft.hinemos.webclient.json.GridDataJson;
 import com.necsoft.hinemos.webclient.servlet.CommonServlet;
+import com.necsoft.hinemos.webclient.util.EndpointManager;
 import com.necsoft.hinemos.webclient.util.ExceptionHandlerUtils;
 import com.necsoft.hinemos.webclient.util.LogUtils;
+import com.necsoft.hinemos.webclient.util.LoginManager;
 import com.necsoft.hinemos.webclient.util.PopulateBeanUtils;
 
 /**
  * This class used for get History info
  * 
- * @version 1.0
- * @since 2011/12/14
- */
+ * @version 1.0.0
+ * @since 1.0.0
+ **/
 public class GetHistoryServlet extends CommonServlet {
     private static final long serialVersionUID = -7775038566425028930L;
 
@@ -66,95 +66,81 @@ public class GetHistoryServlet extends CommonServlet {
             HttpServletResponse response) throws ServletException, IOException,
             HinemosWebAccessException {
 
+        // 中間変数を宣言
         CommonJson result = new CommonJson();
 
         try {
-            // NammingContextを取得する
-            NamingContext namingContext = doLoadNamingContext(request);
-
-            List<List<Object>> listInfoData = doLoadListInfoData(request,
-                    namingContext);
-
-            // Create JSON
-            result = doLoadDataJson(listInfoData);
+            // Get Data
+            ArrayList<ArrayList<Object>> listInfoData = doLoadListInfoData(request);
 
+            // Convert data to JSON structure
+            result = DataProcess.doConvertTableContentToJson(listInfoData);
+            
         } catch (HinemosWebAccessException ex) {
             logUtils.info(ex.getMessage());
             throw new HinemosWebAccessException();
         } catch (HinemosWebRemoteException ex) {
             logUtils.error(ex.getMessage(), ex.getCause());
             result = ExceptionHandlerUtils.doBuildCommonJson(
-                    ExceptionHandlerUtils.LEVEL_WARNING, ex.getMessage());
+                    ExceptionHandlerUtils.LEVEL_WARNING, ex.getMessage(), request.getLocale());
 
         } catch (Exception ex) {
             logUtils.error(ex.getMessage(), ex.getCause());
             result = ExceptionHandlerUtils.doBuildCommonJson(
-                    ExceptionHandlerUtils.LEVEL_ERROR, ex.getMessage());
+                    ExceptionHandlerUtils.LEVEL_ERROR, ex.getMessage(), request.getLocale());
         }
-
         return result;
     }
 
     /**
-     * Get History info
-     * 
-     * @param request
-     *            : HttpServletRequest
-     * @param namingContext
-     *            : NamingContext
-     * @return ArrayList<JobHistory>
-     * @throws Exception
+     * ジョブ[履歴]情報一覧データを取得
      */
-    private List<List<Object>> doLoadListInfoData(HttpServletRequest request,
-            NamingContext namingContext) throws HinemosWebException {
-        //
+    private ArrayList<ArrayList<Object>> doLoadListInfoData(HttpServletRequest request)
+        throws HinemosWebException {
+     
+        // 中間変数を宣言
         HistoryForm form = new HistoryForm();
+        ArrayList<ArrayList<Object>> list = null;
+
         PopulateBeanUtils.populateBean(form, request);
-        List<List<Object>> list;
-
-        // Check filter
-        if (form.isFilter()) {
-            list = processFitler(request, form, namingContext);
-        } else {
-            list = processNoneFilter(request, form, namingContext);
+        
+        //Get loginManager session
+        HttpSession session = request.getSession(true);
+        LoginManager loginManager = null;
+        synchronized(session) {
+            loginManager = (LoginManager) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);        
+         
+            //Check filter
+            if (form.isFilter()) {
+                list = processFitler(request, form, loginManager.endpointManager);
+            } else {
+                list = processNoneFilter(request, form, loginManager.endpointManager);
+            } 
         }
-
         return list;
     }
-
-    /**
-     * Convert data to JSON structure
-     * 
-     * @param listInfoData
-     *            : ArrayList<JobHistory>
-     * @return GridDataJson
-     */
-    private GridDataJson doLoadDataJson(List<List<Object>> list) {
-        GetHistoryBusiness business = new GetHistoryBusiness();
-        return business.doConvertToJson(list);
-    }
-
-    private List<List<Object>> processFitler(HttpServletRequest request,
-            HistoryForm form, NamingContext namingContext)
+    
+    private ArrayList<ArrayList<Object>> processFitler(HttpServletRequest request,
+            HistoryForm form, EndpointManager endpointManager)
             throws HinemosWebException {
         Property condition = doLoadCondition(request);
         GetHistoryBusiness business = new GetHistoryBusiness();
-        return business.getHistory(form, condition, namingContext, request.getLocale());
+        return business.getHistory(form, condition, endpointManager, request.getLocale());
     }
 
-    private List<List<Object>> processNoneFilter(HttpServletRequest request, HistoryForm form,
-            NamingContext namingContext) throws HinemosWebException {
+    private ArrayList<ArrayList<Object>> processNoneFilter(HttpServletRequest request,
+            HistoryForm form, EndpointManager endpointManager) throws HinemosWebException {
         GetHistoryBusiness business = new GetHistoryBusiness();
-        return business.getHistory(form, null, namingContext, request.getLocale());
+        return business.getHistory(form, null, endpointManager, request.getLocale());
     }
 
     private Property doLoadCondition(HttpServletRequest request)
             throws HinemosWebException {
 
-        GetHistoryFilterPropertyBusiness filterProperties = new GetHistoryFilterPropertyBusiness();
+        GetHistoryFilterPropertyBusiness filterProperties = 
+            new GetHistoryFilterPropertyBusiness();
 
-        Property condition = filterProperties.getHistoryFilterProperty(request
-                .getLocale());
+        Property condition = filterProperties.getHistoryFilterProperty(request.getLocale());
         convertCondition(request, condition);
 
         return condition;
