@@ -1,7 +1,7 @@
 /*
  
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
+Copyright (C) NEC Corporation 2012-2013. All Rights Reserved. 
+Copyright (C) NEC Soft, Ltd. 2012-2013. All Rights Reserved. 
  
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
@@ -17,9 +17,8 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.necsoft.hinemos.webclient.monitor;
 
 /**
- * 監視管理機能用の定数を定義するクラス<BR>
+ * 監視管理機能用の定数を定義するクラス
  */
-
 public class MonitorConstants {
 
     // スコープ情報一覧の項目
@@ -29,12 +28,16 @@ public class MonitorConstants {
     public static final int NUMBER_HEADER_STATUS = 11;
     // Set name of filter status properties
     public static final String STATUS_FILTER_PROPERTIES = "status_filter_properties";
-    
+    public static final String STATUS_FILTER_PROPERTIES_LANG = "status_filter_properties_lang";
     
     // イベント情報一覧の項目
     public static final int NUMBER_HEADER_EVENT = 14;
     // Set name of filter event properties
     public static final String EVENT_FILTER_PROPERTIES = "event_filter_properties";
+    public static final String EVENT_FILTER_PROPERTIES_LANG = "event_filter_properties_lang";
+    // Set name of batch confirm properties
+    public static final String EVENT_BATCH_CONFIRM_PROPERTIES = "event_batch_confirm_properties";
+    public static final String EVENT_BATCH_CONFIRM_PROPERTIES_LANG = "event_batch_confirm_properties_lang";
     // 表示件数
     public static final int NUMBER_EVENT_MAX = 100;
     
