@@ -75,12 +75,16 @@ public class GetEventFilterPropertyServlet extends CommonServlet {
         HttpSession session = request.getSession(true);
         Property propertyEvent = (Property) session.
                 getAttribute(MonitorConstants.EVENT_FILTER_PROPERTIES);
+        String lang = (String)session.
+                getAttribute(MonitorConstants.EVENT_FILTER_PROPERTIES_LANG);
+        String cur_lang = request.getLocale().getLanguage();
         // イベント情報一覧を取得
-        if (propertyEvent == null) {
+        if ((propertyEvent == null) || !(cur_lang.equals(lang))) {
             GetEventFilterPropertyBusiness business = new GetEventFilterPropertyBusiness();
             propertyEvent = business.getEventFilterProperty(request.getLocale());
             session.setAttribute(MonitorConstants.EVENT_FILTER_PROPERTIES,
                     propertyEvent);
+            session.setAttribute(MonitorConstants.EVENT_FILTER_PROPERTIES_LANG,cur_lang);
         }
 
         return propertyEvent;
