@@ -1,7 +1,7 @@
 /*
  
-Copyright (C) NEC Corporation 2012. All Rights Reserved. 
-Copyright (C) NEC Soft, Ltd. 2012. All Rights Reserved. 
+Copyright (C) NEC Corporation 2012-2013. All Rights Reserved. 
+Copyright (C) NEC Soft, Ltd. 2012-2013. All Rights Reserved. 
  
 This program is free software; you can redistribute it and/or
 Modify it under the terms of the GNU General Public License 
@@ -19,6 +19,7 @@ package com.necsoft.hinemos.webclient.monitor.servlet;
 import java.io.IOException;
 import java.util.ArrayList;
 import java.util.Date;
+import java.util.Locale;
 import javax.servlet.ServletException;
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
@@ -34,10 +35,13 @@ import com.necsoft.hinemos.webclient.exception.HinemosWebInvalidRequestParameter
 import com.necsoft.hinemos.webclient.exception.HinemosWebRemoteException;
 import com.necsoft.hinemos.webclient.json.CommonJson;
 import com.necsoft.hinemos.webclient.json.GridDataJson;
+import com.necsoft.hinemos.webclient.lang.WebMessages;
 import com.necsoft.hinemos.webclient.monitor.MonitorConstants;
 import com.necsoft.hinemos.webclient.monitor.action.GetEventListTableDefine;
+import com.necsoft.hinemos.webclient.monitor.business.EventBatchConfirmBusiness;
 import com.necsoft.hinemos.webclient.monitor.business.ConfirmEventBusiness;
 import com.necsoft.hinemos.webclient.monitor.business.GetEventListBusiness;
+import com.necsoft.hinemos.webclient.monitor.business.EventUnconfirmBusiness;
 import com.necsoft.hinemos.webclient.monitor.form.MonitorEventForm;
 import com.necsoft.hinemos.webclient.monitor.util.MonitorMappingUtil;
 import com.necsoft.hinemos.webclient.servlet.CommonServlet;
@@ -50,7 +54,7 @@ import com.necsoft.hinemos.webclient.util.PopulateBeanUtils;
 /**
  * イベント情報データをリフレッシュするクラス
  * 
- * @version 1.0.0
+ * @version 2.0.0
  * @since 1.0.0
  **/
 public class GetEventListServlet extends CommonServlet {
@@ -70,7 +74,7 @@ public class GetEventListServlet extends CommonServlet {
             MonitorEventForm form = getDataForm(request);
 
             // Action form
-            doAction(form, request);
+            boolean ret = doAction(form, request);
 
             // 中間変数を宣言
             ArrayList<ArrayList<Object>> listInfoData = doLoadListInfoData(
@@ -78,7 +82,13 @@ public class GetEventListServlet extends CommonServlet {
 
             // Create JSON
             result = doConvertToJson(listInfoData);
-
+            
+            // 確認／未確認に変更／一括確認の実行結果が失敗の場合
+            if (!ret){
+                result.setMessage(WebMessages.getString("exception.data.access", request.getLocale()));
+                result.setResult(1);
+            }
+            
         } catch (HinemosWebAccessException ex) {
             logUtils.info(ex.getMessage());
             throw new HinemosWebAccessException();
@@ -106,44 +116,82 @@ public class GetEventListServlet extends CommonServlet {
     }
 
     /**
+     * 確認／未確認に変更／一括確認の処理を行う
      * @param form
      * @param request
      * @param namingContext
      * @throws HinemosWebException
      */
-    private void doAction(MonitorEventForm form, HttpServletRequest request
+    private boolean doAction(MonitorEventForm form, HttpServletRequest request
             ) throws HinemosWebException {
         String action;
         // Check action
         if (form.getAction() != null) {
             action = form.getAction();
-            if (action.equals("confirmed")) {
+            // get loginManager session
+            HttpSession session = request.getSession(true);
+            LoginManager loginManager = null;
+            
+            if (action.equals("confirmed") || action.equals("unconfirm")) {
                 ArrayList<ArrayList<Object>> list = doGetConfirmedData(request);
                 if (list.size() > 0) {
-                    //get loginManager session
-                    HttpSession session = request.getSession(true);
-                    LoginManager loginManager = null;
                     synchronized(session) {
                         loginManager = (LoginManager) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
-
-                        doConfirmed(list, loginManager.endpointManager);
+                        if (action.equals("confirmed")) {
+                            return doConfirmed(list, loginManager.endpointManager);
+                        }
+                        else {
+                            return doUnconfirm(list, loginManager.endpointManager);
+                        }
                     }
                 }
+            } else if (action.equals("batchconfirm")) {
+                Property condition = doLoadConditionBatchConfirm(request);
+                synchronized(session) {
+                    loginManager = (LoginManager) session.getAttribute(AccessControlConstants.LOGIN_MANAGER);
+                    return doBatchConfirm(form, condition, loginManager.endpointManager, request.getLocale());
+                }
             }
         }
-
+        return true;
     }
 
     /**
      * @param list
      * @throws HinemosWebException
      */
-    private void doConfirmed(ArrayList<ArrayList<Object>> list,
+    private boolean doConfirmed(ArrayList<ArrayList<Object>> list,
         EndpointManager endpointManager) throws HinemosWebException {
         ConfirmEventBusiness eventBusiness = new ConfirmEventBusiness();
-        eventBusiness.confirm(list, endpointManager);
+        return eventBusiness.confirm(list, endpointManager);
     }
-
+    
+    /**
+     * 
+     * @param list
+     * @param endpointManager
+     * @throws HinemosWebException
+     */
+    private boolean doUnconfirm(ArrayList<ArrayList<Object>> list,
+        EndpointManager endpointManager) throws HinemosWebException {
+        EventUnconfirmBusiness eventBusiness = new EventUnconfirmBusiness();
+        return eventBusiness.unconfirm(list, endpointManager);
+    }
+    
+    /**
+     * 
+     * @param form
+     * @param condition
+     * @param endpointManager
+     * @param locale
+     * @throws HinemosWebException
+     */
+    private boolean doBatchConfirm(MonitorEventForm form,
+            Property condition, EndpointManager endpointManager, Locale locale) throws HinemosWebException {
+            EventBatchConfirmBusiness eventBusiness = new EventBatchConfirmBusiness();
+            return eventBusiness.batchconfirm(form, condition, endpointManager, locale);
+    }
+    
     private ArrayList<ArrayList<Object>> doLoadListInfoData(
             HttpServletRequest request, MonitorEventForm form) throws HinemosWebException {
         ArrayList<ArrayList<Object>> listLogData;
@@ -166,7 +214,7 @@ public class GetEventListServlet extends CommonServlet {
 
         return listLogData;
     }
-
+    
     /**
      * @param request
      * @return
@@ -187,6 +235,21 @@ public class GetEventListServlet extends CommonServlet {
         return condition;
     }
 
+    private Property doLoadConditionBatchConfirm(HttpServletRequest request)
+        throws HinemosWebException {
+        HttpSession session = request.getSession(true);
+        
+        if (session.getAttribute(MonitorConstants.EVENT_BATCH_CONFIRM_PROPERTIES) == null) {
+            // HTTPセッションのタイムアウトが発生しました。ログアウトします。
+            throw new HinemosWebException("message.sessiontimeout");
+        }
+        
+        Property condition = (Property) session
+                .getAttribute(MonitorConstants.EVENT_BATCH_CONFIRM_PROPERTIES);
+        convertCondition(request, condition);
+        return condition;
+    }
+    
     private GridDataJson doConvertToJson(ArrayList<ArrayList<Object>> listInfoData)
             throws HinemosWebException {
         return DataProcess.doConvertTableContentToJson(listInfoData);
