@@ -82,12 +82,15 @@ public class GetStatusFilterPropertyServlet extends CommonServlet {
         HttpSession session = request.getSession(true);
         Property propertyStatus = (Property) session
                 .getAttribute(MonitorConstants.STATUS_FILTER_PROPERTIES);
-
-        if (propertyStatus == null) {
+        String lang = (String)session
+                .getAttribute(MonitorConstants.STATUS_FILTER_PROPERTIES_LANG);
+        String cur_lang = request.getLocale().getLanguage();
+        if ((propertyStatus == null) || !(cur_lang.equals(lang))) {
             GetStatusFilterPropertyBusiness business = new GetStatusFilterPropertyBusiness();
             propertyStatus = business.getStatusFilterProperty(request.getLocale());
             session.setAttribute(MonitorConstants.STATUS_FILTER_PROPERTIES,
                     propertyStatus);
+            session.setAttribute(MonitorConstants.STATUS_FILTER_PROPERTIES_LANG,cur_lang);
         }
 
         return propertyStatus;
