@@ -17,12 +17,11 @@ PURPOSE.  See the GNU General Public License for more details.
 package com.necsoft.hinemos.webclient.repository.action;
 
 import java.util.Locale;
-
-import com.clustercontrol.bean.Property;
+import com.necsoft.hinemos.webclient.bean.Property;
 import com.necsoft.hinemos.webclient.repository.util.NodeFilterProperty;
 
 /**
- * ノードフィルタ属性情報を取得するクライアント側アクションクラス<BR>
+ * ノードフィルタ属性情報を取得するクライアント側アクションクラス
  * 
  * @version 1.0.0
  * @since 1.0.0
@@ -30,7 +29,7 @@ import com.necsoft.hinemos.webclient.repository.util.NodeFilterProperty;
 public class GetNodeFilterProperty {
 
     /**
-     * ノードフィルタ属性情報を取得します。<BR>
+     * ノードフィルタ属性情報を取得します。
      * 
      * @return
      */
