@@ -68,10 +68,14 @@ public class GetNodeFilterPropertyServlet extends CommonServlet {
         Property propertyNode = null;
         HttpSession session = request.getSession(true);
         GetNodeFilterPropertyBusiness business = null;
-        if (session.getAttribute(Constants.NODE_FILTER_PROPERTIES) == null) {
+        String lang = (String)session
+            .getAttribute(Constants.NODE_FILTER_PROPERTIES_LANG);
+        String cur_lang = request.getLocale().getLanguage();
+        if (session.getAttribute(Constants.NODE_FILTER_PROPERTIES) == null ||!(cur_lang.equals(lang))) {
             business = new GetNodeFilterPropertyBusiness();
             propertyNode = business.getNodeFilterProperty(request.getLocale());
             session.setAttribute(Constants.NODE_FILTER_PROPERTIES, propertyNode);
+            session.setAttribute(Constants.NODE_FILTER_PROPERTIES_LANG,cur_lang);
         } else {
             propertyNode = (Property) session
                     .getAttribute(Constants.NODE_FILTER_PROPERTIES);
